@import "base";

@primary: #36b24a !important;
@color: white;

@menu-color: #484848;
@menu-background: #ffffff !important;

@menu-color-hover: #484848;
@menu-background-hover: #fff;

@menu-title-color: #484848;
@menu-title-background-color: #fff;

@menu-title-color-hover: #666;
@menu-title-background-color-hover: #f2f3f7;


@navbar-color: #FFF;
@navbar-background: #333333;

.menu {
  .el-menu-item {
    color: @menu-color !important;
  }
}

.logo-wrap {
  background-color: @navbar-background;
  color: @navbar-color;
}