@import "base";

/*主题色*/
@primary: #409eff !important;
@color: white;

/*菜单文本*/
@menu-color: #FFF !important;

/*菜单背景*/
@menu-background: #2c2e39 !important;
@menu-color-hover: #FFF;
@menu-background-hover: #447eff;

@menu-title-color: #fff;
@menu-title-background-color: #202028;

@menu-title-color-hover: #fff;
@menu-title-background-color-hover: #35353e;


@navbar-color: #333;
@navbar-background: #fff;

.menu {
  .el-menu .is-active {
    color: #FFF !important;
    background-color: @menu-background-hover !important;
  }
}