@import "base";

@primary: #2096c8 !important;
@color: white;

@menu-color: #586b7d !important;
@menu-background: #e0e0e0 !important;

@menu-color-hover: #213a53;
@menu-background-hover: #e0e0e0;

@menu-title-color: #586b7d;
@menu-title-background-color: #ededed;

@menu-title-color-hover: #586b7d;
@menu-title-background-color-hover: #ededed;


@navbar-color: #edf6ff;
@navbar-background: #213a53;
.logo-wrap {
  color: @navbar-color !important;
  background-color: @navbar-background;
}

.menu .el-menu .is-active {
  color: @menu-color-hover !important;
}